<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label-width="120" label="总成序列号" prop="sfcCode">
        <el-input
          v-model="queryParams.sfcCode"
          placeholder="请输入总成序列号"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="工位编码" prop="locationCode">
        <el-input
          v-model="queryParams.locationCode"
          placeholder="请输入工位编码"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
<!--      <el-form-item label="参数集编码" prop="paramSetCode">-->
<!--        <el-input-->
<!--          v-model="queryParams.paramSetCode"-->
<!--          placeholder="请输入参数集编码"-->
<!--          clearable-->
<!--          @keyup.enter.native="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="参数集名称" prop="paramSetName">-->
<!--        <el-input-->
<!--          v-model="queryParams.paramSetName"-->
<!--          placeholder="请输入参数集名称"-->
<!--          clearable-->
<!--          @keyup.enter.native="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="采集时间" prop="collectTime">-->
<!--        <el-date-picker clearable-->
<!--          v-model="queryParams.collectTime"-->
<!--          type="date"-->
<!--          value-format="yyyy-MM-dd"-->
<!--          placeholder="请选择采集时间">-->
<!--        </el-date-picker>-->
<!--      </el-form-item>-->
      <el-form-item style="float: right">
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
<!--        <el-button icon="el-icon-setting" size="mini" @click="toggleAdvancedSearch">高级查询</el-button>-->
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['da:tightenCollection:add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['da:tightenCollection:edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['da:tightenCollection:remove']"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
          v-hasPermi="['da:tightenCollection:export']"
        >导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table border v-loading="loading" :data="tightenCollectionList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
<!--      <el-table-column label="主键id" align="center" prop="id" />-->
      <el-table-column label="总成序列号" align="center" prop="sfcCode" />
      <el-table-column label="工位编码" align="center" prop="locationCode" />
      <el-table-column label="参数集编码" align="center" prop="paramSetCode" />
      <el-table-column label="参数集名称" align="center" prop="paramSetName" />
      <el-table-column label="扭矩值" align="center" prop="torque" />
      <el-table-column label="扭矩状态" align="center" prop="torqueStatus" />
      <el-table-column label="角度值" align="center" prop="angle" />
      <el-table-column label="角度状态" align="center" prop="angleStatus" />
      <el-table-column label="采集时间" align="center" prop="collectTime" width="180">
      </el-table-column>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['da:tightenCollection:edit']"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['da:tightenCollection:remove']"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改拧紧采集对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="100px">
        <el-form-item label="总成序列号" prop="sfcCode">
          <el-input v-model="form.sfcCode" placeholder="请输入总成序列号" />
        </el-form-item>
        <el-form-item label="工位编码" prop="locationCode">
          <el-input v-model="form.locationCode" placeholder="请输入工位编码" />
        </el-form-item>
        <el-form-item label="参数集编码" prop="paramSetCode">
          <el-input v-model="form.paramSetCode" placeholder="请输入参数集编码" />
        </el-form-item>
        <el-form-item label="参数集名称" prop="paramSetName">
          <el-input v-model="form.paramSetName" placeholder="请输入参数集名称" />
        </el-form-item>
        <el-form-item label="扭矩值" prop="torque">
          <el-input v-model="form.torque" placeholder="请输入扭矩值" />
        </el-form-item>
        <el-form-item label="角度值" prop="angle">
          <el-input v-model="form.angle" placeholder="请输入角度值" />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listTightenCollection, getTightenCollection, delTightenCollection, addTightenCollection, updateTightenCollection } from "@/api/main/da/tightenCollection";

export default {
  name: "TightenCollection",
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 拧紧采集表格数据
      tightenCollectionList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        sfcCode: null,
        locationCode: null,
        paramSetCode: null,
        paramSetName: null,
        torqueStatus: null,
        angleStatus: null,
        collectTime: null
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
      }
    };
  },
  created() {
    this.getList();
  },
  methods: {
    toggleAdvancedSearch() {
      this.advancedSearchVisible = !this.advancedSearchVisible;
    },
    /** 查询拧紧采集列表 */
    getList() {
      this.loading = true;
      listTightenCollection(this.queryParams).then(response => {
        this.tightenCollectionList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        sfcCode: null,
        locationCode: null,
        paramSetCode: null,
        paramSetName: null,
        torque: null,
        torqueStatus: null,
        angle: null,
        angleStatus: null,
        collectTime: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加拧紧采集";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getTightenCollection(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改拧紧采集";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateTightenCollection(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addTightenCollection(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除拧紧采集编号为"' + ids + '"的数据项？').then(function() {
        return delTightenCollection(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('da/tightenCollection/export', {
        ...this.queryParams
      }, `tightenCollection_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
